# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: hyperspace.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'hyperspace.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10hyperspace.proto\x12\nhyperspace\"0\n\x12ReplicationRequest\x12\x1a\n\x12last_logical_clock\x18\x01 \x01(\x04\"\xaa\x02\n\x0eReplicationLog\x12\x15\n\rlogical_clock\x18\x01 \x01(\x04\x12\x16\n\x0eorigin_node_id\x18\x02 \x01(\t\x12\x12\n\ncollection\x18\x03 \x01(\t\x12&\n\x06insert\x18\x04 \x01(\x0b\x32\x14.hyperspace.InsertOpH\x00\x12;\n\x11\x63reate_collection\x18\x05 \x01(\x0b\x32\x1e.hyperspace.CreateCollectionOpH\x00\x12;\n\x11\x64\x65lete_collection\x18\x06 \x01(\x0b\x32\x1e.hyperspace.DeleteCollectionOpH\x00\x12&\n\x06\x64\x65lete\x18\x07 \x01(\x0b\x32\x14.hyperspace.DeleteOpH\x00\x42\x0b\n\toperation\"\x9f\x02\n\x08InsertOp\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0e\n\x06vector\x18\x02 \x03(\x01\x12\x34\n\x08metadata\x18\x03 \x03(\x0b\x32\".hyperspace.InsertOp.MetadataEntry\x12?\n\x0etyped_metadata\x18\x04 \x03(\x0b\x32\'.hyperspace.InsertOp.TypedMetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aO\n\x12TypedMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.hyperspace.MetadataValue:\x02\x38\x01\"7\n\x12\x43reateCollectionOp\x12\x11\n\tdimension\x18\x01 \x01(\r\x12\x0e\n\x06metric\x18\x02 \x01(\t\"\x14\n\x12\x44\x65leteCollectionOp\"\x16\n\x08\x44\x65leteOp\x12\n\n\x02id\x18\x01 \x01(\r\"@\n\x12QuantizationConfig\x12*\n\x04mode\x18\x01 \x01(\x0e\x32\x1c.hyperspace.QuantizationMode\"J\n\x17\x43reateCollectionRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdimension\x18\x02 \x01(\r\x12\x0e\n\x06metric\x18\x03 \x01(\t\"\'\n\x17\x44\x65leteCollectionRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\".\n\x17ListCollectionsResponse\x12\x13\n\x0b\x63ollections\x18\x01 \x03(\t\"&\n\x16\x43ollectionStatsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"c\n\x17\x43ollectionStatsResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x04\x12\x11\n\tdimension\x18\x02 \x01(\r\x12\x0e\n\x06metric\x18\x03 \x01(\t\x12\x16\n\x0eindexing_queue\x18\x04 \x01(\x04\"n\n\x13RebuildIndexRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x38\n\x0c\x66ilter_query\x18\x02 \x01(\x0b\x32\x1d.hyperspace.VacuumFilterQueryH\x00\x88\x01\x01\x42\x0f\n\r_filter_query\"z\n\x0c\x43onfigUpdate\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x16\n\tef_search\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1c\n\x0f\x65\x66_construction\x18\x03 \x01(\rH\x01\x88\x01\x01\x42\x0c\n\n_ef_searchB\x12\n\x10_ef_construction\";\n\x11VacuumFilterQuery\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\n\n\x02op\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x01\"Z\n\x16ReconsolidationRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x15\n\rtarget_vector\x18\x02 \x03(\x01\x12\x15\n\rlearning_rate\x18\x03 \x01(\x01\"\xa2\x03\n\rInsertRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x0e\n\x06vector\x18\x02 \x03(\x01\x12\n\n\x02id\x18\x03 \x01(\r\x12\x39\n\x08metadata\x18\x04 \x03(\x0b\x32\'.hyperspace.InsertRequest.MetadataEntry\x12\x16\n\x0eorigin_node_id\x18\x05 \x01(\t\x12\x15\n\rlogical_clock\x18\x06 \x01(\x04\x12/\n\ndurability\x18\x07 \x01(\x0e\x32\x1b.hyperspace.DurabilityLevel\x12\x44\n\x0etyped_metadata\x18\x08 \x03(\x0b\x32,.hyperspace.InsertRequest.TypedMetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aO\n\x12TypedMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.hyperspace.MetadataValue:\x02\x38\x01\"\xa5\x02\n\nVectorData\x12\x0e\n\x06vector\x18\x01 \x03(\x01\x12\n\n\x02id\x18\x02 \x01(\r\x12\x36\n\x08metadata\x18\x03 \x03(\x0b\x32$.hyperspace.VectorData.MetadataEntry\x12\x41\n\x0etyped_metadata\x18\x04 \x03(\x0b\x32).hyperspace.VectorData.TypedMetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aO\n\x12TypedMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.hyperspace.MetadataValue:\x02\x38\x01\"\xb1\x01\n\x12\x42\x61tchInsertRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\'\n\x07vectors\x18\x02 \x03(\x0b\x32\x16.hyperspace.VectorData\x12\x16\n\x0eorigin_node_id\x18\x03 \x01(\t\x12\x15\n\rlogical_clock\x18\x04 \x01(\x04\x12/\n\ndurability\x18\x05 \x01(\x0e\x32\x1b.hyperspace.DurabilityLevel\"\xe2\x01\n\x11InsertTextRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\r\x12\x0c\n\x04text\x18\x03 \x01(\t\x12=\n\x08metadata\x18\x04 \x03(\x0b\x32+.hyperspace.InsertTextRequest.MetadataEntry\x12/\n\ndurability\x18\x05 \x01(\x0e\x32\x1b.hyperspace.DurabilityLevel\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"0\n\x10VectorizeRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0e\n\x06metric\x18\x02 \x01(\t\"#\n\x11VectorizeResponse\x12\x0e\n\x06vector\x18\x01 \x03(\x01\"\xd3\x01\n\x11SearchTextRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\r\n\x05top_k\x18\x03 \x01(\r\x12\x39\n\x06\x66ilter\x18\x04 \x03(\x0b\x32).hyperspace.SearchTextRequest.FilterEntry\x12#\n\x07\x66ilters\x18\x05 \x03(\x0b\x32\x12.hyperspace.Filter\x1a-\n\x0b\x46ilterEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"!\n\x0eInsertResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"/\n\rDeleteRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\r\"!\n\x0e\x44\x65leteResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\xbe\x02\n\rSearchRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x0e\n\x06vector\x18\x02 \x03(\x01\x12\r\n\x05top_k\x18\x03 \x01(\r\x12\x35\n\x06\x66ilter\x18\x04 \x03(\x0b\x32%.hyperspace.SearchRequest.FilterEntry\x12#\n\x07\x66ilters\x18\x05 \x03(\x0b\x32\x12.hyperspace.Filter\x12\x19\n\x0chybrid_query\x18\x06 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0chybrid_alpha\x18\x07 \x01(\x02H\x01\x88\x01\x01\x12\x17\n\x0fuse_wasserstein\x18\x08 \x01(\x08\x1a-\n\x0b\x46ilterEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\r_hybrid_queryB\x0f\n\r_hybrid_alpha\"]\n\x06\x46ilter\x12\"\n\x05match\x18\x01 \x01(\x0b\x32\x11.hyperspace.MatchH\x00\x12\"\n\x05range\x18\x02 \x01(\x0b\x32\x11.hyperspace.RangeH\x00\x42\x0b\n\tcondition\"#\n\x05Match\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x8c\x01\n\x05Range\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x03gte\x18\x02 \x01(\x03H\x00\x88\x01\x01\x12\x10\n\x03lte\x18\x03 \x01(\x03H\x01\x88\x01\x01\x12\x14\n\x07gte_f64\x18\x04 \x01(\x01H\x02\x88\x01\x01\x12\x14\n\x07lte_f64\x18\x05 \x01(\x01H\x03\x88\x01\x01\x42\x06\n\x04_gteB\x06\n\x04_lteB\n\n\x08_gte_f64B\n\n\x08_lte_f64\";\n\x0eSearchResponse\x12)\n\x07results\x18\x01 \x03(\x0b\x32\x18.hyperspace.SearchResult\"A\n\x12\x42\x61tchSearchRequest\x12+\n\x08searches\x18\x01 \x03(\x0b\x32\x19.hyperspace.SearchRequest\"D\n\x13\x42\x61tchSearchResponse\x12-\n\tresponses\x18\x01 \x03(\x0b\x32\x1a.hyperspace.SearchResponse\"R\n\x1cSearchMultiCollectionRequest\x12\x13\n\x0b\x63ollections\x18\x01 \x03(\t\x12\x0e\n\x06vector\x18\x02 \x03(\x01\x12\r\n\x05top_k\x18\x03 \x01(\r\"\xba\x01\n\x1dSearchMultiCollectionResponse\x12K\n\tresponses\x18\x01 \x03(\x0b\x32\x38.hyperspace.SearchMultiCollectionResponse.ResponsesEntry\x1aL\n\x0eResponsesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.hyperspace.SearchResponse:\x02\x38\x01\"\xad\x02\n\x0cSearchResult\x12\n\n\x02id\x18\x01 \x01(\r\x12\x10\n\x08\x64istance\x18\x02 \x01(\x01\x12\x38\n\x08metadata\x18\x03 \x03(\x0b\x32&.hyperspace.SearchResult.MetadataEntry\x12\x43\n\x0etyped_metadata\x18\x04 \x03(\x0b\x32+.hyperspace.SearchResult.TypedMetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aO\n\x12TypedMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.hyperspace.MetadataValue:\x02\x38\x01\"?\n\x0eGetNodeRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\r\x12\r\n\x05layer\x18\x03 \x01(\r\"\xb4\x02\n\tGraphNode\x12\n\n\x02id\x18\x01 \x01(\r\x12\r\n\x05layer\x18\x02 \x01(\r\x12\x11\n\tneighbors\x18\x03 \x03(\r\x12\x35\n\x08metadata\x18\x04 \x03(\x0b\x32#.hyperspace.GraphNode.MetadataEntry\x12@\n\x0etyped_metadata\x18\x05 \x03(\x0b\x32(.hyperspace.GraphNode.TypedMetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aO\n\x12TypedMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.hyperspace.MetadataValue:\x02\x38\x01\"c\n\x13GetNeighborsRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\r\x12\r\n\x05layer\x18\x03 \x01(\r\x12\r\n\x05limit\x18\x04 \x01(\r\x12\x0e\n\x06offset\x18\x05 \x01(\r\"V\n\x14GetNeighborsResponse\x12(\n\tneighbors\x18\x01 \x03(\x0b\x32\x15.hyperspace.GraphNode\x12\x14\n\x0c\x65\x64ge_weights\x18\x02 \x03(\x01\"\xf9\x01\n\x0fTraverseRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x10\n\x08start_id\x18\x02 \x01(\r\x12\x11\n\tmax_depth\x18\x03 \x01(\r\x12\x11\n\tmax_nodes\x18\x04 \x01(\r\x12\r\n\x05layer\x18\x05 \x01(\r\x12\x37\n\x06\x66ilter\x18\x06 \x03(\x0b\x32\'.hyperspace.TraverseRequest.FilterEntry\x12#\n\x07\x66ilters\x18\x07 \x03(\x0b\x32\x12.hyperspace.Filter\x1a-\n\x0b\x46ilterEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"8\n\x10TraverseResponse\x12$\n\x05nodes\x18\x01 \x03(\x0b\x32\x15.hyperspace.GraphNode\"\x83\x01\n\x1b\x46indSemanticClustersRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\r\n\x05layer\x18\x02 \x01(\r\x12\x18\n\x10min_cluster_size\x18\x03 \x01(\r\x12\x14\n\x0cmax_clusters\x18\x04 \x01(\r\x12\x11\n\tmax_nodes\x18\x05 \x01(\r\"X\n\x18GetConceptParentsRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\r\x12\r\n\x05layer\x18\x03 \x01(\r\x12\r\n\x05limit\x18\x04 \x01(\r\"C\n\x19GetConceptParentsResponse\x12&\n\x07parents\x18\x01 \x03(\x0b\x32\x15.hyperspace.GraphNode\" \n\x0cGraphCluster\x12\x10\n\x08node_ids\x18\x01 \x03(\r\"J\n\x1c\x46indSemanticClustersResponse\x12*\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x18.hyperspace.GraphCluster\"r\n\rMetadataValue\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x03 \x01(\x01H\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x42\x06\n\x04kind\"h\n\x18\x45ventSubscriptionRequest\x12$\n\x05types\x18\x01 \x03(\x0e\x32\x15.hyperspace.EventType\x12\x17\n\ncollection\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_collection\"\xf3\x02\n\x13VectorInsertedEvent\x12\n\n\x02id\x18\x01 \x01(\r\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x15\n\rlogical_clock\x18\x03 \x01(\x04\x12\x16\n\x0eorigin_node_id\x18\x04 \x01(\t\x12?\n\x08metadata\x18\x05 \x03(\x0b\x32-.hyperspace.VectorInsertedEvent.MetadataEntry\x12J\n\x0etyped_metadata\x18\x06 \x03(\x0b\x32\x32.hyperspace.VectorInsertedEvent.TypedMetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aO\n\x12TypedMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.hyperspace.MetadataValue:\x02\x38\x01\"c\n\x12VectorDeletedEvent\x12\n\n\x02id\x18\x01 \x01(\r\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x15\n\rlogical_clock\x18\x03 \x01(\x04\x12\x16\n\x0eorigin_node_id\x18\x04 \x01(\t\"\xb4\x01\n\x0c\x45ventMessage\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.hyperspace.EventType\x12:\n\x0fvector_inserted\x18\x02 \x01(\x0b\x32\x1f.hyperspace.VectorInsertedEventH\x00\x12\x38\n\x0evector_deleted\x18\x03 \x01(\x0b\x32\x1e.hyperspace.VectorDeletedEventH\x00\x42\t\n\x07payload\"\x07\n\x05\x45mpty\" \n\x0eStatusResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\"\x10\n\x0eMonitorRequest\"e\n\x0bSystemStats\x12\x19\n\x11total_collections\x18\x01 \x01(\x04\x12\x15\n\rtotal_vectors\x18\x02 \x01(\x04\x12\x17\n\x0ftotal_memory_mb\x18\x03 \x01(\x01\x12\x0b\n\x03qps\x18\x04 \x01(\x01\"#\n\rDigestRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\"[\n\x0e\x44igestResponse\x12\x15\n\rlogical_clock\x18\x01 \x01(\x04\x12\x12\n\nstate_hash\x18\x02 \x01(\x04\x12\x0f\n\x07\x62uckets\x18\x03 \x03(\x04\x12\r\n\x05\x63ount\x18\x04 \x01(\x04\"v\n\x14SyncHandshakeRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x16\n\x0e\x63lient_buckets\x18\x02 \x03(\x04\x12\x1c\n\x14\x63lient_logical_clock\x18\x03 \x01(\x04\x12\x14\n\x0c\x63lient_count\x18\x04 \x01(\x04\"L\n\nDiffBucket\x12\x14\n\x0c\x62ucket_index\x18\x01 \x01(\r\x12\x13\n\x0bserver_hash\x18\x02 \x01(\x04\x12\x13\n\x0b\x63lient_hash\x18\x03 \x01(\x04\"\x8a\x01\n\x15SyncHandshakeResponse\x12,\n\x0c\x64iff_buckets\x18\x01 \x03(\x0b\x32\x16.hyperspace.DiffBucket\x12\x1c\n\x14server_logical_clock\x18\x02 \x01(\x04\x12\x14\n\x0cserver_count\x18\x03 \x01(\x04\x12\x0f\n\x07in_sync\x18\x04 \x01(\x08\"=\n\x0fSyncPullRequest\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x16\n\x0e\x62ucket_indices\x18\x02 \x03(\r\"\xc3\x01\n\x0eSyncVectorData\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\r\x12\x0e\n\x06vector\x18\x03 \x03(\x01\x12:\n\x08metadata\x18\x04 \x03(\x0b\x32(.hyperspace.SyncVectorData.MetadataEntry\x12\x14\n\x0c\x62ucket_index\x18\x05 \x01(\r\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"J\n\x10SyncPushResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\r\x12\x10\n\x08rejected\x18\x02 \x01(\r\x12\x12\n\nduplicates\x18\x03 \x01(\r*+\n\x10QuantizationMode\x12\x08\n\x04NONE\x10\x00\x12\r\n\tSCALAR_I8\x10\x01*F\n\x0f\x44urabilityLevel\x12\x11\n\rDEFAULT_LEVEL\x10\x00\x12\t\n\x05\x41SYNC\x10\x01\x12\t\n\x05\x42\x41TCH\x10\x02\x12\n\n\x06STRICT\x10\x03*G\n\tEventType\x12\x11\n\rEVENT_UNKNOWN\x10\x00\x12\x13\n\x0fVECTOR_INSERTED\x10\x01\x12\x12\n\x0eVECTOR_DELETED\x10\x02\x32\xa4\x12\n\x08\x44\x61tabase\x12S\n\x10\x43reateCollection\x12#.hyperspace.CreateCollectionRequest\x1a\x1a.hyperspace.StatusResponse\x12S\n\x10\x44\x65leteCollection\x12#.hyperspace.DeleteCollectionRequest\x1a\x1a.hyperspace.StatusResponse\x12I\n\x0fListCollections\x12\x11.hyperspace.Empty\x1a#.hyperspace.ListCollectionsResponse\x12]\n\x12GetCollectionStats\x12\".hyperspace.CollectionStatsRequest\x1a#.hyperspace.CollectionStatsResponse\x12?\n\x06Insert\x12\x19.hyperspace.InsertRequest\x1a\x1a.hyperspace.InsertResponse\x12I\n\x0b\x42\x61tchInsert\x12\x1e.hyperspace.BatchInsertRequest\x1a\x1a.hyperspace.InsertResponse\x12G\n\nInsertText\x12\x1d.hyperspace.InsertTextRequest\x1a\x1a.hyperspace.InsertResponse\x12H\n\tVectorize\x12\x1c.hyperspace.VectorizeRequest\x1a\x1d.hyperspace.VectorizeResponse\x12G\n\nSearchText\x12\x1d.hyperspace.SearchTextRequest\x1a\x1a.hyperspace.SearchResponse\x12?\n\x06\x44\x65lete\x12\x19.hyperspace.DeleteRequest\x1a\x1a.hyperspace.DeleteResponse\x12?\n\x06Search\x12\x19.hyperspace.SearchRequest\x1a\x1a.hyperspace.SearchResponse\x12N\n\x0bSearchBatch\x12\x1e.hyperspace.BatchSearchRequest\x1a\x1f.hyperspace.BatchSearchResponse\x12l\n\x15SearchMultiCollection\x12(.hyperspace.SearchMultiCollectionRequest\x1a).hyperspace.SearchMultiCollectionResponse\x12<\n\x07GetNode\x12\x1a.hyperspace.GetNodeRequest\x1a\x15.hyperspace.GraphNode\x12Q\n\x0cGetNeighbors\x12\x1f.hyperspace.GetNeighborsRequest\x1a .hyperspace.GetNeighborsResponse\x12`\n\x11GetConceptParents\x12$.hyperspace.GetConceptParentsRequest\x1a%.hyperspace.GetConceptParentsResponse\x12\x45\n\x08Traverse\x12\x1b.hyperspace.TraverseRequest\x1a\x1c.hyperspace.TraverseResponse\x12i\n\x14\x46indSemanticClusters\x12\'.hyperspace.FindSemanticClustersRequest\x1a(.hyperspace.FindSemanticClustersResponse\x12@\n\x07Monitor\x12\x1a.hyperspace.MonitorRequest\x1a\x17.hyperspace.SystemStats0\x01\x12@\n\x0fTriggerSnapshot\x12\x11.hyperspace.Empty\x1a\x1a.hyperspace.StatusResponse\x12>\n\rTriggerVacuum\x12\x11.hyperspace.Empty\x1a\x1a.hyperspace.StatusResponse\x12X\n\x16TriggerReconsolidation\x12\".hyperspace.ReconsolidationRequest\x1a\x1a.hyperspace.StatusResponse\x12\x41\n\tConfigure\x12\x18.hyperspace.ConfigUpdate\x1a\x1a.hyperspace.StatusResponse\x12I\n\tReplicate\x12\x1e.hyperspace.ReplicationRequest\x1a\x1a.hyperspace.ReplicationLog0\x01\x12U\n\x11SubscribeToEvents\x12$.hyperspace.EventSubscriptionRequest\x1a\x18.hyperspace.EventMessage0\x01\x12\x42\n\tGetDigest\x12\x19.hyperspace.DigestRequest\x1a\x1a.hyperspace.DigestResponse\x12K\n\x0cRebuildIndex\x12\x1f.hyperspace.RebuildIndexRequest\x1a\x1a.hyperspace.StatusResponse\x12T\n\rSyncHandshake\x12 .hyperspace.SyncHandshakeRequest\x1a!.hyperspace.SyncHandshakeResponse\x12\x45\n\x08SyncPull\x12\x1b.hyperspace.SyncPullRequest\x1a\x1a.hyperspace.SyncVectorData0\x01\x12\x46\n\x08SyncPush\x12\x1a.hyperspace.SyncVectorData\x1a\x1c.hyperspace.SyncPushResponse(\x01\x42,Z*github.com/yarlabs/hyperspace-sdk-go/protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperspace_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z*github.com/yarlabs/hyperspace-sdk-go/proto'
  _globals['_INSERTOP_METADATAENTRY']._loaded_options = None
  _globals['_INSERTOP_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INSERTOP_TYPEDMETADATAENTRY']._loaded_options = None
  _globals['_INSERTOP_TYPEDMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_INSERTREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_INSERTREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INSERTREQUEST_TYPEDMETADATAENTRY']._loaded_options = None
  _globals['_INSERTREQUEST_TYPEDMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_VECTORDATA_METADATAENTRY']._loaded_options = None
  _globals['_VECTORDATA_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_VECTORDATA_TYPEDMETADATAENTRY']._loaded_options = None
  _globals['_VECTORDATA_TYPEDMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_INSERTTEXTREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_INSERTTEXTREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_SEARCHTEXTREQUEST_FILTERENTRY']._loaded_options = None
  _globals['_SEARCHTEXTREQUEST_FILTERENTRY']._serialized_options = b'8\001'
  _globals['_SEARCHREQUEST_FILTERENTRY']._loaded_options = None
  _globals['_SEARCHREQUEST_FILTERENTRY']._serialized_options = b'8\001'
  _globals['_SEARCHMULTICOLLECTIONRESPONSE_RESPONSESENTRY']._loaded_options = None
  _globals['_SEARCHMULTICOLLECTIONRESPONSE_RESPONSESENTRY']._serialized_options = b'8\001'
  _globals['_SEARCHRESULT_METADATAENTRY']._loaded_options = None
  _globals['_SEARCHRESULT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_SEARCHRESULT_TYPEDMETADATAENTRY']._loaded_options = None
  _globals['_SEARCHRESULT_TYPEDMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_GRAPHNODE_METADATAENTRY']._loaded_options = None
  _globals['_GRAPHNODE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GRAPHNODE_TYPEDMETADATAENTRY']._loaded_options = None
  _globals['_GRAPHNODE_TYPEDMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_TRAVERSEREQUEST_FILTERENTRY']._loaded_options = None
  _globals['_TRAVERSEREQUEST_FILTERENTRY']._serialized_options = b'8\001'
  _globals['_VECTORINSERTEDEVENT_METADATAENTRY']._loaded_options = None
  _globals['_VECTORINSERTEDEVENT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_VECTORINSERTEDEVENT_TYPEDMETADATAENTRY']._loaded_options = None
  _globals['_VECTORINSERTEDEVENT_TYPEDMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_SYNCVECTORDATA_METADATAENTRY']._loaded_options = None
  _globals['_SYNCVECTORDATA_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_QUANTIZATIONMODE']._serialized_start=7582
  _globals['_QUANTIZATIONMODE']._serialized_end=7625
  _globals['_DURABILITYLEVEL']._serialized_start=7627
  _globals['_DURABILITYLEVEL']._serialized_end=7697
  _globals['_EVENTTYPE']._serialized_start=7699
  _globals['_EVENTTYPE']._serialized_end=7770
  _globals['_REPLICATIONREQUEST']._serialized_start=32
  _globals['_REPLICATIONREQUEST']._serialized_end=80
  _globals['_REPLICATIONLOG']._serialized_start=83
  _globals['_REPLICATIONLOG']._serialized_end=381
  _globals['_INSERTOP']._serialized_start=384
  _globals['_INSERTOP']._serialized_end=671
  _globals['_INSERTOP_METADATAENTRY']._serialized_start=543
  _globals['_INSERTOP_METADATAENTRY']._serialized_end=590
  _globals['_INSERTOP_TYPEDMETADATAENTRY']._serialized_start=592
  _globals['_INSERTOP_TYPEDMETADATAENTRY']._serialized_end=671
  _globals['_CREATECOLLECTIONOP']._serialized_start=673
  _globals['_CREATECOLLECTIONOP']._serialized_end=728
  _globals['_DELETECOLLECTIONOP']._serialized_start=730
  _globals['_DELETECOLLECTIONOP']._serialized_end=750
  _globals['_DELETEOP']._serialized_start=752
  _globals['_DELETEOP']._serialized_end=774
  _globals['_QUANTIZATIONCONFIG']._serialized_start=776
  _globals['_QUANTIZATIONCONFIG']._serialized_end=840
  _globals['_CREATECOLLECTIONREQUEST']._serialized_start=842
  _globals['_CREATECOLLECTIONREQUEST']._serialized_end=916
  _globals['_DELETECOLLECTIONREQUEST']._serialized_start=918
  _globals['_DELETECOLLECTIONREQUEST']._serialized_end=957
  _globals['_LISTCOLLECTIONSRESPONSE']._serialized_start=959
  _globals['_LISTCOLLECTIONSRESPONSE']._serialized_end=1005
  _globals['_COLLECTIONSTATSREQUEST']._serialized_start=1007
  _globals['_COLLECTIONSTATSREQUEST']._serialized_end=1045
  _globals['_COLLECTIONSTATSRESPONSE']._serialized_start=1047
  _globals['_COLLECTIONSTATSRESPONSE']._serialized_end=1146
  _globals['_REBUILDINDEXREQUEST']._serialized_start=1148
  _globals['_REBUILDINDEXREQUEST']._serialized_end=1258
  _globals['_CONFIGUPDATE']._serialized_start=1260
  _globals['_CONFIGUPDATE']._serialized_end=1382
  _globals['_VACUUMFILTERQUERY']._serialized_start=1384
  _globals['_VACUUMFILTERQUERY']._serialized_end=1443
  _globals['_RECONSOLIDATIONREQUEST']._serialized_start=1445
  _globals['_RECONSOLIDATIONREQUEST']._serialized_end=1535
  _globals['_INSERTREQUEST']._serialized_start=1538
  _globals['_INSERTREQUEST']._serialized_end=1956
  _globals['_INSERTREQUEST_METADATAENTRY']._serialized_start=543
  _globals['_INSERTREQUEST_METADATAENTRY']._serialized_end=590
  _globals['_INSERTREQUEST_TYPEDMETADATAENTRY']._serialized_start=592
  _globals['_INSERTREQUEST_TYPEDMETADATAENTRY']._serialized_end=671
  _globals['_VECTORDATA']._serialized_start=1959
  _globals['_VECTORDATA']._serialized_end=2252
  _globals['_VECTORDATA_METADATAENTRY']._serialized_start=543
  _globals['_VECTORDATA_METADATAENTRY']._serialized_end=590
  _globals['_VECTORDATA_TYPEDMETADATAENTRY']._serialized_start=592
  _globals['_VECTORDATA_TYPEDMETADATAENTRY']._serialized_end=671
  _globals['_BATCHINSERTREQUEST']._serialized_start=2255
  _globals['_BATCHINSERTREQUEST']._serialized_end=2432
  _globals['_INSERTTEXTREQUEST']._serialized_start=2435
  _globals['_INSERTTEXTREQUEST']._serialized_end=2661
  _globals['_INSERTTEXTREQUEST_METADATAENTRY']._serialized_start=543
  _globals['_INSERTTEXTREQUEST_METADATAENTRY']._serialized_end=590
  _globals['_VECTORIZEREQUEST']._serialized_start=2663
  _globals['_VECTORIZEREQUEST']._serialized_end=2711
  _globals['_VECTORIZERESPONSE']._serialized_start=2713
  _globals['_VECTORIZERESPONSE']._serialized_end=2748
  _globals['_SEARCHTEXTREQUEST']._serialized_start=2751
  _globals['_SEARCHTEXTREQUEST']._serialized_end=2962
  _globals['_SEARCHTEXTREQUEST_FILTERENTRY']._serialized_start=2917
  _globals['_SEARCHTEXTREQUEST_FILTERENTRY']._serialized_end=2962
  _globals['_INSERTRESPONSE']._serialized_start=2964
  _globals['_INSERTRESPONSE']._serialized_end=2997
  _globals['_DELETEREQUEST']._serialized_start=2999
  _globals['_DELETEREQUEST']._serialized_end=3046
  _globals['_DELETERESPONSE']._serialized_start=3048
  _globals['_DELETERESPONSE']._serialized_end=3081
  _globals['_SEARCHREQUEST']._serialized_start=3084
  _globals['_SEARCHREQUEST']._serialized_end=3402
  _globals['_SEARCHREQUEST_FILTERENTRY']._serialized_start=2917
  _globals['_SEARCHREQUEST_FILTERENTRY']._serialized_end=2962
  _globals['_FILTER']._serialized_start=3404
  _globals['_FILTER']._serialized_end=3497
  _globals['_MATCH']._serialized_start=3499
  _globals['_MATCH']._serialized_end=3534
  _globals['_RANGE']._serialized_start=3537
  _globals['_RANGE']._serialized_end=3677
  _globals['_SEARCHRESPONSE']._serialized_start=3679
  _globals['_SEARCHRESPONSE']._serialized_end=3738
  _globals['_BATCHSEARCHREQUEST']._serialized_start=3740
  _globals['_BATCHSEARCHREQUEST']._serialized_end=3805
  _globals['_BATCHSEARCHRESPONSE']._serialized_start=3807
  _globals['_BATCHSEARCHRESPONSE']._serialized_end=3875
  _globals['_SEARCHMULTICOLLECTIONREQUEST']._serialized_start=3877
  _globals['_SEARCHMULTICOLLECTIONREQUEST']._serialized_end=3959
  _globals['_SEARCHMULTICOLLECTIONRESPONSE']._serialized_start=3962
  _globals['_SEARCHMULTICOLLECTIONRESPONSE']._serialized_end=4148
  _globals['_SEARCHMULTICOLLECTIONRESPONSE_RESPONSESENTRY']._serialized_start=4072
  _globals['_SEARCHMULTICOLLECTIONRESPONSE_RESPONSESENTRY']._serialized_end=4148
  _globals['_SEARCHRESULT']._serialized_start=4151
  _globals['_SEARCHRESULT']._serialized_end=4452
  _globals['_SEARCHRESULT_METADATAENTRY']._serialized_start=543
  _globals['_SEARCHRESULT_METADATAENTRY']._serialized_end=590
  _globals['_SEARCHRESULT_TYPEDMETADATAENTRY']._serialized_start=592
  _globals['_SEARCHRESULT_TYPEDMETADATAENTRY']._serialized_end=671
  _globals['_GETNODEREQUEST']._serialized_start=4454
  _globals['_GETNODEREQUEST']._serialized_end=4517
  _globals['_GRAPHNODE']._serialized_start=4520
  _globals['_GRAPHNODE']._serialized_end=4828
  _globals['_GRAPHNODE_METADATAENTRY']._serialized_start=543
  _globals['_GRAPHNODE_METADATAENTRY']._serialized_end=590
  _globals['_GRAPHNODE_TYPEDMETADATAENTRY']._serialized_start=592
  _globals['_GRAPHNODE_TYPEDMETADATAENTRY']._serialized_end=671
  _globals['_GETNEIGHBORSREQUEST']._serialized_start=4830
  _globals['_GETNEIGHBORSREQUEST']._serialized_end=4929
  _globals['_GETNEIGHBORSRESPONSE']._serialized_start=4931
  _globals['_GETNEIGHBORSRESPONSE']._serialized_end=5017
  _globals['_TRAVERSEREQUEST']._serialized_start=5020
  _globals['_TRAVERSEREQUEST']._serialized_end=5269
  _globals['_TRAVERSEREQUEST_FILTERENTRY']._serialized_start=2917
  _globals['_TRAVERSEREQUEST_FILTERENTRY']._serialized_end=2962
  _globals['_TRAVERSERESPONSE']._serialized_start=5271
  _globals['_TRAVERSERESPONSE']._serialized_end=5327
  _globals['_FINDSEMANTICCLUSTERSREQUEST']._serialized_start=5330
  _globals['_FINDSEMANTICCLUSTERSREQUEST']._serialized_end=5461
  _globals['_GETCONCEPTPARENTSREQUEST']._serialized_start=5463
  _globals['_GETCONCEPTPARENTSREQUEST']._serialized_end=5551
  _globals['_GETCONCEPTPARENTSRESPONSE']._serialized_start=5553
  _globals['_GETCONCEPTPARENTSRESPONSE']._serialized_end=5620
  _globals['_GRAPHCLUSTER']._serialized_start=5622
  _globals['_GRAPHCLUSTER']._serialized_end=5654
  _globals['_FINDSEMANTICCLUSTERSRESPONSE']._serialized_start=5656
  _globals['_FINDSEMANTICCLUSTERSRESPONSE']._serialized_end=5730
  _globals['_METADATAVALUE']._serialized_start=5732
  _globals['_METADATAVALUE']._serialized_end=5846
  _globals['_EVENTSUBSCRIPTIONREQUEST']._serialized_start=5848
  _globals['_EVENTSUBSCRIPTIONREQUEST']._serialized_end=5952
  _globals['_VECTORINSERTEDEVENT']._serialized_start=5955
  _globals['_VECTORINSERTEDEVENT']._serialized_end=6326
  _globals['_VECTORINSERTEDEVENT_METADATAENTRY']._serialized_start=543
  _globals['_VECTORINSERTEDEVENT_METADATAENTRY']._serialized_end=590
  _globals['_VECTORINSERTEDEVENT_TYPEDMETADATAENTRY']._serialized_start=592
  _globals['_VECTORINSERTEDEVENT_TYPEDMETADATAENTRY']._serialized_end=671
  _globals['_VECTORDELETEDEVENT']._serialized_start=6328
  _globals['_VECTORDELETEDEVENT']._serialized_end=6427
  _globals['_EVENTMESSAGE']._serialized_start=6430
  _globals['_EVENTMESSAGE']._serialized_end=6610
  _globals['_EMPTY']._serialized_start=6612
  _globals['_EMPTY']._serialized_end=6619
  _globals['_STATUSRESPONSE']._serialized_start=6621
  _globals['_STATUSRESPONSE']._serialized_end=6653
  _globals['_MONITORREQUEST']._serialized_start=6655
  _globals['_MONITORREQUEST']._serialized_end=6671
  _globals['_SYSTEMSTATS']._serialized_start=6673
  _globals['_SYSTEMSTATS']._serialized_end=6774
  _globals['_DIGESTREQUEST']._serialized_start=6776
  _globals['_DIGESTREQUEST']._serialized_end=6811
  _globals['_DIGESTRESPONSE']._serialized_start=6813
  _globals['_DIGESTRESPONSE']._serialized_end=6904
  _globals['_SYNCHANDSHAKEREQUEST']._serialized_start=6906
  _globals['_SYNCHANDSHAKEREQUEST']._serialized_end=7024
  _globals['_DIFFBUCKET']._serialized_start=7026
  _globals['_DIFFBUCKET']._serialized_end=7102
  _globals['_SYNCHANDSHAKERESPONSE']._serialized_start=7105
  _globals['_SYNCHANDSHAKERESPONSE']._serialized_end=7243
  _globals['_SYNCPULLREQUEST']._serialized_start=7245
  _globals['_SYNCPULLREQUEST']._serialized_end=7306
  _globals['_SYNCVECTORDATA']._serialized_start=7309
  _globals['_SYNCVECTORDATA']._serialized_end=7504
  _globals['_SYNCVECTORDATA_METADATAENTRY']._serialized_start=543
  _globals['_SYNCVECTORDATA_METADATAENTRY']._serialized_end=590
  _globals['_SYNCPUSHRESPONSE']._serialized_start=7506
  _globals['_SYNCPUSHRESPONSE']._serialized_end=7580
  _globals['_DATABASE']._serialized_start=7773
  _globals['_DATABASE']._serialized_end=10113
# @@protoc_insertion_point(module_scope)
