# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import hyperspace_pb2 as hyperspace__pb2

GRPC_GENERATED_VERSION = '1.78.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in hyperspace_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class DatabaseStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateCollection = channel.unary_unary(
                '/hyperspace.Database/CreateCollection',
                request_serializer=hyperspace__pb2.CreateCollectionRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.StatusResponse.FromString,
                _registered_method=True)
        self.DeleteCollection = channel.unary_unary(
                '/hyperspace.Database/DeleteCollection',
                request_serializer=hyperspace__pb2.DeleteCollectionRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.StatusResponse.FromString,
                _registered_method=True)
        self.ListCollections = channel.unary_unary(
                '/hyperspace.Database/ListCollections',
                request_serializer=hyperspace__pb2.Empty.SerializeToString,
                response_deserializer=hyperspace__pb2.ListCollectionsResponse.FromString,
                _registered_method=True)
        self.GetCollectionStats = channel.unary_unary(
                '/hyperspace.Database/GetCollectionStats',
                request_serializer=hyperspace__pb2.CollectionStatsRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.CollectionStatsResponse.FromString,
                _registered_method=True)
        self.Insert = channel.unary_unary(
                '/hyperspace.Database/Insert',
                request_serializer=hyperspace__pb2.InsertRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.InsertResponse.FromString,
                _registered_method=True)
        self.BatchInsert = channel.unary_unary(
                '/hyperspace.Database/BatchInsert',
                request_serializer=hyperspace__pb2.BatchInsertRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.InsertResponse.FromString,
                _registered_method=True)
        self.InsertText = channel.unary_unary(
                '/hyperspace.Database/InsertText',
                request_serializer=hyperspace__pb2.InsertTextRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.InsertResponse.FromString,
                _registered_method=True)
        self.Vectorize = channel.unary_unary(
                '/hyperspace.Database/Vectorize',
                request_serializer=hyperspace__pb2.VectorizeRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.VectorizeResponse.FromString,
                _registered_method=True)
        self.SearchText = channel.unary_unary(
                '/hyperspace.Database/SearchText',
                request_serializer=hyperspace__pb2.SearchTextRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.SearchResponse.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/hyperspace.Database/Delete',
                request_serializer=hyperspace__pb2.DeleteRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.DeleteResponse.FromString,
                _registered_method=True)
        self.Search = channel.unary_unary(
                '/hyperspace.Database/Search',
                request_serializer=hyperspace__pb2.SearchRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.SearchResponse.FromString,
                _registered_method=True)
        self.SearchBatch = channel.unary_unary(
                '/hyperspace.Database/SearchBatch',
                request_serializer=hyperspace__pb2.BatchSearchRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.BatchSearchResponse.FromString,
                _registered_method=True)
        self.SearchMultiCollection = channel.unary_unary(
                '/hyperspace.Database/SearchMultiCollection',
                request_serializer=hyperspace__pb2.SearchMultiCollectionRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.SearchMultiCollectionResponse.FromString,
                _registered_method=True)
        self.GetNode = channel.unary_unary(
                '/hyperspace.Database/GetNode',
                request_serializer=hyperspace__pb2.GetNodeRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.GraphNode.FromString,
                _registered_method=True)
        self.GetNeighbors = channel.unary_unary(
                '/hyperspace.Database/GetNeighbors',
                request_serializer=hyperspace__pb2.GetNeighborsRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.GetNeighborsResponse.FromString,
                _registered_method=True)
        self.GetConceptParents = channel.unary_unary(
                '/hyperspace.Database/GetConceptParents',
                request_serializer=hyperspace__pb2.GetConceptParentsRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.GetConceptParentsResponse.FromString,
                _registered_method=True)
        self.Traverse = channel.unary_unary(
                '/hyperspace.Database/Traverse',
                request_serializer=hyperspace__pb2.TraverseRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.TraverseResponse.FromString,
                _registered_method=True)
        self.FindSemanticClusters = channel.unary_unary(
                '/hyperspace.Database/FindSemanticClusters',
                request_serializer=hyperspace__pb2.FindSemanticClustersRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.FindSemanticClustersResponse.FromString,
                _registered_method=True)
        self.Monitor = channel.unary_stream(
                '/hyperspace.Database/Monitor',
                request_serializer=hyperspace__pb2.MonitorRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.SystemStats.FromString,
                _registered_method=True)
        self.TriggerSnapshot = channel.unary_unary(
                '/hyperspace.Database/TriggerSnapshot',
                request_serializer=hyperspace__pb2.Empty.SerializeToString,
                response_deserializer=hyperspace__pb2.StatusResponse.FromString,
                _registered_method=True)
        self.TriggerVacuum = channel.unary_unary(
                '/hyperspace.Database/TriggerVacuum',
                request_serializer=hyperspace__pb2.Empty.SerializeToString,
                response_deserializer=hyperspace__pb2.StatusResponse.FromString,
                _registered_method=True)
        self.TriggerReconsolidation = channel.unary_unary(
                '/hyperspace.Database/TriggerReconsolidation',
                request_serializer=hyperspace__pb2.ReconsolidationRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.StatusResponse.FromString,
                _registered_method=True)
        self.Configure = channel.unary_unary(
                '/hyperspace.Database/Configure',
                request_serializer=hyperspace__pb2.ConfigUpdate.SerializeToString,
                response_deserializer=hyperspace__pb2.StatusResponse.FromString,
                _registered_method=True)
        self.Replicate = channel.unary_stream(
                '/hyperspace.Database/Replicate',
                request_serializer=hyperspace__pb2.ReplicationRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.ReplicationLog.FromString,
                _registered_method=True)
        self.SubscribeToEvents = channel.unary_stream(
                '/hyperspace.Database/SubscribeToEvents',
                request_serializer=hyperspace__pb2.EventSubscriptionRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.EventMessage.FromString,
                _registered_method=True)
        self.GetDigest = channel.unary_unary(
                '/hyperspace.Database/GetDigest',
                request_serializer=hyperspace__pb2.DigestRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.DigestResponse.FromString,
                _registered_method=True)
        self.RebuildIndex = channel.unary_unary(
                '/hyperspace.Database/RebuildIndex',
                request_serializer=hyperspace__pb2.RebuildIndexRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.StatusResponse.FromString,
                _registered_method=True)
        self.SyncHandshake = channel.unary_unary(
                '/hyperspace.Database/SyncHandshake',
                request_serializer=hyperspace__pb2.SyncHandshakeRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.SyncHandshakeResponse.FromString,
                _registered_method=True)
        self.SyncPull = channel.unary_stream(
                '/hyperspace.Database/SyncPull',
                request_serializer=hyperspace__pb2.SyncPullRequest.SerializeToString,
                response_deserializer=hyperspace__pb2.SyncVectorData.FromString,
                _registered_method=True)
        self.SyncPush = channel.stream_unary(
                '/hyperspace.Database/SyncPush',
                request_serializer=hyperspace__pb2.SyncVectorData.SerializeToString,
                response_deserializer=hyperspace__pb2.SyncPushResponse.FromString,
                _registered_method=True)


class DatabaseServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateCollection(self, request, context):
        """Collection Management
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCollection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCollections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollectionStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Insert(self, request, context):
        """Insert vectors
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchInsert(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsertText(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Vectorize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchText(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete vectors
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Search(self, request, context):
        """Search (ANN)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchBatch(self, request, context):
        """Batch Search (ANN)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchMultiCollection(self, request, context):
        """Multi-Geometry Search (v3.0)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNode(self, request, context):
        """Graph Traversal API (v2.3)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNeighbors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConceptParents(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Traverse(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindSemanticClusters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Monitor(self, request, context):
        """Stream statistics for TUI (Global or Collection tailored)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerSnapshot(self, request, context):
        """Admin Controls
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerVacuum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerReconsolidation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Configure(self, request, context):
        """Dynamic Configuration
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Replicate(self, request, context):
        """Replication (Leader -> Follower)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeToEvents(self, request, context):
        """CDC/Event Stream (External subscribers)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDigest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RebuildIndex(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SyncHandshake(self, request, context):
        """Delta Sync (Merkle Tree — Task 2.1)
        Step 1: Client sends its digest, server returns which buckets differ.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SyncPull(self, request, context):
        """Step 2: Client requests vectors from specific buckets, server streams them.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SyncPush(self, request_iterator, context):
        """Step 3 (optional): Client pushes its unique vectors to the server.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DatabaseServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateCollection': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCollection,
                    request_deserializer=hyperspace__pb2.CreateCollectionRequest.FromString,
                    response_serializer=hyperspace__pb2.StatusResponse.SerializeToString,
            ),
            'DeleteCollection': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCollection,
                    request_deserializer=hyperspace__pb2.DeleteCollectionRequest.FromString,
                    response_serializer=hyperspace__pb2.StatusResponse.SerializeToString,
            ),
            'ListCollections': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCollections,
                    request_deserializer=hyperspace__pb2.Empty.FromString,
                    response_serializer=hyperspace__pb2.ListCollectionsResponse.SerializeToString,
            ),
            'GetCollectionStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollectionStats,
                    request_deserializer=hyperspace__pb2.CollectionStatsRequest.FromString,
                    response_serializer=hyperspace__pb2.CollectionStatsResponse.SerializeToString,
            ),
            'Insert': grpc.unary_unary_rpc_method_handler(
                    servicer.Insert,
                    request_deserializer=hyperspace__pb2.InsertRequest.FromString,
                    response_serializer=hyperspace__pb2.InsertResponse.SerializeToString,
            ),
            'BatchInsert': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchInsert,
                    request_deserializer=hyperspace__pb2.BatchInsertRequest.FromString,
                    response_serializer=hyperspace__pb2.InsertResponse.SerializeToString,
            ),
            'InsertText': grpc.unary_unary_rpc_method_handler(
                    servicer.InsertText,
                    request_deserializer=hyperspace__pb2.InsertTextRequest.FromString,
                    response_serializer=hyperspace__pb2.InsertResponse.SerializeToString,
            ),
            'Vectorize': grpc.unary_unary_rpc_method_handler(
                    servicer.Vectorize,
                    request_deserializer=hyperspace__pb2.VectorizeRequest.FromString,
                    response_serializer=hyperspace__pb2.VectorizeResponse.SerializeToString,
            ),
            'SearchText': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchText,
                    request_deserializer=hyperspace__pb2.SearchTextRequest.FromString,
                    response_serializer=hyperspace__pb2.SearchResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=hyperspace__pb2.DeleteRequest.FromString,
                    response_serializer=hyperspace__pb2.DeleteResponse.SerializeToString,
            ),
            'Search': grpc.unary_unary_rpc_method_handler(
                    servicer.Search,
                    request_deserializer=hyperspace__pb2.SearchRequest.FromString,
                    response_serializer=hyperspace__pb2.SearchResponse.SerializeToString,
            ),
            'SearchBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchBatch,
                    request_deserializer=hyperspace__pb2.BatchSearchRequest.FromString,
                    response_serializer=hyperspace__pb2.BatchSearchResponse.SerializeToString,
            ),
            'SearchMultiCollection': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchMultiCollection,
                    request_deserializer=hyperspace__pb2.SearchMultiCollectionRequest.FromString,
                    response_serializer=hyperspace__pb2.SearchMultiCollectionResponse.SerializeToString,
            ),
            'GetNode': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNode,
                    request_deserializer=hyperspace__pb2.GetNodeRequest.FromString,
                    response_serializer=hyperspace__pb2.GraphNode.SerializeToString,
            ),
            'GetNeighbors': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNeighbors,
                    request_deserializer=hyperspace__pb2.GetNeighborsRequest.FromString,
                    response_serializer=hyperspace__pb2.GetNeighborsResponse.SerializeToString,
            ),
            'GetConceptParents': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConceptParents,
                    request_deserializer=hyperspace__pb2.GetConceptParentsRequest.FromString,
                    response_serializer=hyperspace__pb2.GetConceptParentsResponse.SerializeToString,
            ),
            'Traverse': grpc.unary_unary_rpc_method_handler(
                    servicer.Traverse,
                    request_deserializer=hyperspace__pb2.TraverseRequest.FromString,
                    response_serializer=hyperspace__pb2.TraverseResponse.SerializeToString,
            ),
            'FindSemanticClusters': grpc.unary_unary_rpc_method_handler(
                    servicer.FindSemanticClusters,
                    request_deserializer=hyperspace__pb2.FindSemanticClustersRequest.FromString,
                    response_serializer=hyperspace__pb2.FindSemanticClustersResponse.SerializeToString,
            ),
            'Monitor': grpc.unary_stream_rpc_method_handler(
                    servicer.Monitor,
                    request_deserializer=hyperspace__pb2.MonitorRequest.FromString,
                    response_serializer=hyperspace__pb2.SystemStats.SerializeToString,
            ),
            'TriggerSnapshot': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerSnapshot,
                    request_deserializer=hyperspace__pb2.Empty.FromString,
                    response_serializer=hyperspace__pb2.StatusResponse.SerializeToString,
            ),
            'TriggerVacuum': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerVacuum,
                    request_deserializer=hyperspace__pb2.Empty.FromString,
                    response_serializer=hyperspace__pb2.StatusResponse.SerializeToString,
            ),
            'TriggerReconsolidation': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerReconsolidation,
                    request_deserializer=hyperspace__pb2.ReconsolidationRequest.FromString,
                    response_serializer=hyperspace__pb2.StatusResponse.SerializeToString,
            ),
            'Configure': grpc.unary_unary_rpc_method_handler(
                    servicer.Configure,
                    request_deserializer=hyperspace__pb2.ConfigUpdate.FromString,
                    response_serializer=hyperspace__pb2.StatusResponse.SerializeToString,
            ),
            'Replicate': grpc.unary_stream_rpc_method_handler(
                    servicer.Replicate,
                    request_deserializer=hyperspace__pb2.ReplicationRequest.FromString,
                    response_serializer=hyperspace__pb2.ReplicationLog.SerializeToString,
            ),
            'SubscribeToEvents': grpc.unary_stream_rpc_method_handler(
                    servicer.SubscribeToEvents,
                    request_deserializer=hyperspace__pb2.EventSubscriptionRequest.FromString,
                    response_serializer=hyperspace__pb2.EventMessage.SerializeToString,
            ),
            'GetDigest': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDigest,
                    request_deserializer=hyperspace__pb2.DigestRequest.FromString,
                    response_serializer=hyperspace__pb2.DigestResponse.SerializeToString,
            ),
            'RebuildIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.RebuildIndex,
                    request_deserializer=hyperspace__pb2.RebuildIndexRequest.FromString,
                    response_serializer=hyperspace__pb2.StatusResponse.SerializeToString,
            ),
            'SyncHandshake': grpc.unary_unary_rpc_method_handler(
                    servicer.SyncHandshake,
                    request_deserializer=hyperspace__pb2.SyncHandshakeRequest.FromString,
                    response_serializer=hyperspace__pb2.SyncHandshakeResponse.SerializeToString,
            ),
            'SyncPull': grpc.unary_stream_rpc_method_handler(
                    servicer.SyncPull,
                    request_deserializer=hyperspace__pb2.SyncPullRequest.FromString,
                    response_serializer=hyperspace__pb2.SyncVectorData.SerializeToString,
            ),
            'SyncPush': grpc.stream_unary_rpc_method_handler(
                    servicer.SyncPush,
                    request_deserializer=hyperspace__pb2.SyncVectorData.FromString,
                    response_serializer=hyperspace__pb2.SyncPushResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'hyperspace.Database', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('hyperspace.Database', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Database(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateCollection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/CreateCollection',
            hyperspace__pb2.CreateCollectionRequest.SerializeToString,
            hyperspace__pb2.StatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteCollection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/DeleteCollection',
            hyperspace__pb2.DeleteCollectionRequest.SerializeToString,
            hyperspace__pb2.StatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListCollections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/ListCollections',
            hyperspace__pb2.Empty.SerializeToString,
            hyperspace__pb2.ListCollectionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCollectionStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/GetCollectionStats',
            hyperspace__pb2.CollectionStatsRequest.SerializeToString,
            hyperspace__pb2.CollectionStatsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Insert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/Insert',
            hyperspace__pb2.InsertRequest.SerializeToString,
            hyperspace__pb2.InsertResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchInsert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/BatchInsert',
            hyperspace__pb2.BatchInsertRequest.SerializeToString,
            hyperspace__pb2.InsertResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InsertText(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/InsertText',
            hyperspace__pb2.InsertTextRequest.SerializeToString,
            hyperspace__pb2.InsertResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Vectorize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/Vectorize',
            hyperspace__pb2.VectorizeRequest.SerializeToString,
            hyperspace__pb2.VectorizeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SearchText(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/SearchText',
            hyperspace__pb2.SearchTextRequest.SerializeToString,
            hyperspace__pb2.SearchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/Delete',
            hyperspace__pb2.DeleteRequest.SerializeToString,
            hyperspace__pb2.DeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Search(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/Search',
            hyperspace__pb2.SearchRequest.SerializeToString,
            hyperspace__pb2.SearchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SearchBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/SearchBatch',
            hyperspace__pb2.BatchSearchRequest.SerializeToString,
            hyperspace__pb2.BatchSearchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SearchMultiCollection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/SearchMultiCollection',
            hyperspace__pb2.SearchMultiCollectionRequest.SerializeToString,
            hyperspace__pb2.SearchMultiCollectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/GetNode',
            hyperspace__pb2.GetNodeRequest.SerializeToString,
            hyperspace__pb2.GraphNode.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNeighbors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/GetNeighbors',
            hyperspace__pb2.GetNeighborsRequest.SerializeToString,
            hyperspace__pb2.GetNeighborsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetConceptParents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/GetConceptParents',
            hyperspace__pb2.GetConceptParentsRequest.SerializeToString,
            hyperspace__pb2.GetConceptParentsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Traverse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/Traverse',
            hyperspace__pb2.TraverseRequest.SerializeToString,
            hyperspace__pb2.TraverseResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindSemanticClusters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/FindSemanticClusters',
            hyperspace__pb2.FindSemanticClustersRequest.SerializeToString,
            hyperspace__pb2.FindSemanticClustersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Monitor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/hyperspace.Database/Monitor',
            hyperspace__pb2.MonitorRequest.SerializeToString,
            hyperspace__pb2.SystemStats.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TriggerSnapshot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/TriggerSnapshot',
            hyperspace__pb2.Empty.SerializeToString,
            hyperspace__pb2.StatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TriggerVacuum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/TriggerVacuum',
            hyperspace__pb2.Empty.SerializeToString,
            hyperspace__pb2.StatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TriggerReconsolidation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/TriggerReconsolidation',
            hyperspace__pb2.ReconsolidationRequest.SerializeToString,
            hyperspace__pb2.StatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Configure(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/Configure',
            hyperspace__pb2.ConfigUpdate.SerializeToString,
            hyperspace__pb2.StatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Replicate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/hyperspace.Database/Replicate',
            hyperspace__pb2.ReplicationRequest.SerializeToString,
            hyperspace__pb2.ReplicationLog.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubscribeToEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/hyperspace.Database/SubscribeToEvents',
            hyperspace__pb2.EventSubscriptionRequest.SerializeToString,
            hyperspace__pb2.EventMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDigest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/GetDigest',
            hyperspace__pb2.DigestRequest.SerializeToString,
            hyperspace__pb2.DigestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RebuildIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/RebuildIndex',
            hyperspace__pb2.RebuildIndexRequest.SerializeToString,
            hyperspace__pb2.StatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SyncHandshake(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperspace.Database/SyncHandshake',
            hyperspace__pb2.SyncHandshakeRequest.SerializeToString,
            hyperspace__pb2.SyncHandshakeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SyncPull(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/hyperspace.Database/SyncPull',
            hyperspace__pb2.SyncPullRequest.SerializeToString,
            hyperspace__pb2.SyncVectorData.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SyncPush(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/hyperspace.Database/SyncPush',
            hyperspace__pb2.SyncVectorData.SerializeToString,
            hyperspace__pb2.SyncPushResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
